@@ -25,7 +25,7 @@ import six
 from six.moves import range
 import urllib3
 
-__version__ = '4.8.1'
+__version__ = '4.8.4'
 VERSION = __version__  # TODO: remove when bumping major version.
 
 logger = logging.getLogger(__name__)
@@ -530,7 +530,7 @@ class Consumer(object):
         connection or HTTP 5xx error; 0 to fail after first attempt.
     :param int retry_backoff_factor: In case of retries, controls sleep time. e.g.,
         sleep_seconds = backoff_factor * (2 ^ (num_total_retries - 1)).
-    :param bool verify_cert: whether to verify the server certificate. Recommended.
+    :param bool verify_cert: whether to verify the server certificate.
 
     .. versionadded:: 4.6.0
         The *api_host* parameter.
@@ -540,7 +540,7 @@ class Consumer(object):
 
     def __init__(self, events_url=None, people_url=None, import_url=None,
             request_timeout=None, groups_url=None, api_host="api.mixpanel.com",
-            retry_limit=4, retry_backoff_factor=0.25, verify_cert=True):
+            retry_limit=4, retry_backoff_factor=0.25, verify_cert=False):
         # TODO: With next major version, make the above args kwarg-only, and reorder them.
         self._endpoints = {
             'events': events_url or 'https://{}/track'.format(api_host),
@@ -548,17 +548,30 @@ class Consumer(object):
             'groups': groups_url or 'https://{}/groups'.format(api_host),
             'imports': import_url or 'https://{}/import'.format(api_host),
         }
-        retry_config = urllib3.Retry(
-            total=retry_limit,
-            backoff_factor=retry_backoff_factor,
-            method_whitelist={'POST'},
-            status_forcelist=set(range(500, 600)),
-        )
+
+        retry_args = {
+            "total": retry_limit,
+            "backoff_factor": retry_backoff_factor,
+            "status_forcelist": set(range(500, 600)),
+        }
+
+        # Work around renamed argument in urllib3.
+        if hasattr(urllib3.util.Retry.DEFAULT, "allowed_methods"):
+            methods_arg = "allowed_methods"
+        else:
+            methods_arg = "method_whitelist"
+
+        retry_args[methods_arg] = {"POST"}
+        retry_config = urllib3.Retry(**retry_args)
+
+        if not verify_cert:
+            urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
+
         cert_reqs = 'CERT_REQUIRED' if verify_cert else 'CERT_NONE'
         self._http = urllib3.PoolManager(
             retries=retry_config,
             timeout=urllib3.Timeout(request_timeout),
-            cert_reqs=cert_reqs,
+            cert_reqs=str(cert_reqs),
         )
 
     def send(self, endpoint, json_message, api_key=None, api_secret=None):
@@ -641,7 +654,7 @@ class BufferedConsumer(object):
         connection or HTTP 5xx error; 0 to fail after first attempt.
     :param int retry_backoff_factor: In case of retries, controls sleep time. e.g.,
         sleep_seconds = backoff_factor * (2 ^ (num_total_retries - 1)).
-    :param bool verify_cert: whether to verify the server certificate. Recommended.
+    :param bool verify_cert: whether to verify the server certificate.
 
     .. versionadded:: 4.6.0
         The *api_host* parameter.
@@ -656,7 +669,7 @@ class BufferedConsumer(object):
     """
     def __init__(self, max_size=50, events_url=None, people_url=None, import_url=None,
             request_timeout=None, groups_url=None, api_host="api.mixpanel.com",
-            retry_limit=4, retry_backoff_factor=0.25, verify_cert=True):
+            retry_limit=4, retry_backoff_factor=0.25, verify_cert=False):
         self._consumer = Consumer(events_url, people_url, import_url, request_timeout,
             groups_url, api_host, retry_limit, retry_backoff_factor, verify_cert)
         self._buffers = {
